0.9.0
-----

* New mechanism to allow some options to be stored in a configuration file, but
  also to be entered in command line (overriding the conf file), and finally
  having a fallback value:

  * ``hostname``, ``user`` and ``cluster name``
  * The configuration file is  ``~/.sperato.conf``
